'use strict';

/******************************************
 * configure grunt tasks to perform in dev 
 * environment only
 * *****************************************/

module.exports = function (grunt) {

    require('dotenv').config();

    //require('load-grunt-tasks')(grunt);

    const build_path = 'build/';

    // load tasks    
    grunt.loadNpmTasks('gruntify-eslint');

    grunt.loadNpmTasks('grunt-webpack');

    grunt.loadNpmTasks('grunt-browser-sync');

    grunt.loadNpmTasks('grunt-contrib-cssmin');

    grunt.loadNpmTasks('grunt-contrib-watch');

    grunt.loadNpmTasks('grunt-commands');

    require('load-grunt-tasks')(grunt);

    var mochaCmd = 'mocha ./src/server/test/**/*.js --compilers js:babel-core/register --bail --color'

    // load webpack configuration
    var webpackConfig = require('./../../../webpack.config');


    // set database variables   
    var host = process.env.DB_HOST;
    var port = process.env.DB_PORT;
    var database = process.env.DB_NAME;
    var username = process.env.DB_HOST_USERNAME;
    var password = process.env.DB_HOST_PASSWORD;
    var dialect = process.env.DB_DIALECT;

    var modelsDir = './src/server/schema/models/';
    // generate database models with sequelize-auto
    var schemaCmd = 'sequelize-auto -o ' + modelsDir + ' -d ' + database + ' -h ' + host + ' -u ' + username + ' -p ' + port + ' -x ' + password + ' -e ' + dialect + '';


    // grunt.initConfig({
    //     webpack: {
    //         options: webpackConfig
    //     }
    // });
    grunt.config.set('clean', {
        all: build_path + '*',         // clean all files within build folder 
        readme: build_path + '**/*.md'    // remove all files having .md ext   
    });

    grunt.config.set('cssmin', {
        target: {
            files: {
                'assets/css/app.min.css': ['assets/css/style.css', 'assets/css/responsive.css'],
                'assets/css/react-component.min.css': ['assets/css/react-datetime.css', 'assets/css/react-select.css']
            }
        }
    })

    grunt.config.set('eslint', {
        options: {
            silent: true
        },
        src: ['src/client/**/*.js', 'src/server/**/*.js', 'Gruntfile.js', 'webpack.config.js', '!public/dist/*.js']
    });

    grunt.config.set('watch', {
        app: {
            files: ['assets/css/*', 'src/**/*', 'webpack.config.js', 'Gruntfile.js'],
            tasks: ['eslint', 'shell:dev'],
            options: {
                spawn: false,
            }
        }
    });


    grunt.config.set('shell', {
        options: {
            stdout: true,
            stderr: true
        },
        generate_schema: {
            command: schemaCmd
        },
        dev: {
            command: [
                'pm2 startOrRestart process.json',
                //'nodemon --watch src/ --interpreter babel-node src/server/development.js',
                // nodemon --watch src/ --exec babel-node src/server/development.js,
            ].join('&&')
        },
        mocha: {
            command: mochaCmd
        }

    });


    grunt.config.set('copy', {
        main: {
            files: [
                { expand: true, src: ['assets/**'], dest: build_path },
                { src: ['package.json'], dest: build_path },
                { src: ['bower.json'], dest: build_path },
                { src: ['load.env.js'], dest: build_path },
                { src: ['webpack.config.js'], dest: build_path },
                { src: ['process.json'], dest: build_path },
                { src: ['Gruntfile.js'], dest: build_path },
                { src: ['.env'], dest: build_path },
            ]
        }
    });
};