const path = require('path');

var webpack = require('webpack');
var ExtractTextPlugin = require('extract-text-webpack-plugin');
var BrowserSyncPlugin = require('browser-sync-webpack-plugin');
var CompressionPlugin = require("compression-webpack-plugin");

module.exports = {
    entry: './src/client/app.js',
    output: {
        path: path.resolve('assets/'),
        filename: 'bundle-[name].js',
        publicPath: '/static/',
        chunkFilename: "[id].chunk.js"
    },
    module: {
        loaders: [
            { test: /\.js$/, loader: 'babel-loader', exclude: /node_modules/ },
            { test: /\.jsx$/, loader: 'babel-loader', exclude: /node_modules/ },
            { test: /\.json$/, loader: "json-loader" },
            {
                test: /\.css$/,
                loader: ExtractTextPlugin.extract("style-loader", "css-loader!autoprefixer-loader")
            },
            {
                test: /\.eot(\?v=\d+\.\d+\.\d+)?$/,
                loader: "file-loader"
            },
            {
                test: /\.(woff|woff2)$/,
                loader: "file-loader"
            },
            {
                test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/,
                loader: "file-loader"
            },
            {
                test: /\.svg(\?v=\d+\.\d+\.\d+)?$/,
                loader: "file-loader"
            },
            {
                test: /\.ico(\?v=\d+\.\d+\.\d+)?$/,
                loader: "file-loader"
            }
        ]
    },
    plugins: [
        new BrowserSyncPlugin({
            codeSync: true,               // send file changes to connected browsers and reload
            proxy: process.env.SITE_URL,  // local node app address            
            port: 3001,                   // *different* port than abovey
            notify: true,
            open: 'external',             // open with ip or localhost
            files: [path.resolve(process.cwd(), 'src/client/**')]
        }),
        new CompressionPlugin({
            asset: "[path].gz[query]",
            algorithm: "gzip",
            test: /\.js$/,
            minRatio: 0.8
        }),
        new ExtractTextPlugin("bundle.css"),
        new webpack.DefinePlugin({
            "process.env": { NODE_ENV: '"development"' }
        })
    ]
};
