'use strict';

/*************************************
 * main file to create server instance,
 * set views, singleton instances, api routes,
 * react router 
 * *************************************/

// load modules


var Express = require('express');
var path = require('path');
var exphbs = require('express-handlebars');
var bodyParser = require('body-parser');
var compression = require('compression');
var helmet = require('helmet');
var logging = require('./middlewares/logging');
var cookieParser = require('cookie-parser');
var customApi = require('./api');

require('babel-register');

// initialize our express app
const app = Express();

app.use(cookieParser('someKnownLongSecretStringHere'));
app.use(compression());

// configure app to use bodyParser()
// this will let us get the data from a POST
app.use(bodyParser.urlencoded({ limit: '150mb', extended: true }));
app.use(bodyParser.json({ limit: '150mb' }));

// set view path
app.set('views', path.join(__dirname, '../client/views'));
app.engine('handlebars', exphbs());
// setup handlebars for templating
app.set('view engine', 'handlebars');

// Add CORS on ExpressJS
app.use(function (req, res, next) {
    res.header('Access-Control-Allow-Origin', '*');
    res.header('Access-Control-Allow-Headers', 'Origin, X-Requested-With, Content-Type, Accept');
    next();
});

// static assets
app.use('/static', Express.static(path.join(__dirname, '../../assets')));
app.use('/bower_components', Express.static(path.join(__dirname, '../../bower_components')));

// protect app from web vulnerabilities by setting HTTP headers appropriately
// Hide X-Powered-By
app.use(helmet.hidePoweredBy());


// server api routes 
app.use('/api', customApi);

app.use('/*', function(req, res, next){
    res.render('app');
});



// universal routing and rendering
//ADD ISOMORPHIC 
// app.use(reactRouter);


// error logging
app.use(logging);

module.exports = app;
