/**
 * This file will help us connect to the database
 * when the app starting and then any controller can just
 * use the the db object returned by the get method.
 * It will always be the same db object because require caches the result the first time it is called.
*/
import Promise from 'bluebird';

var mongoClient = require('mongodb').MongoClient;

const state = {
    db: null
};

exports.connect = function (url, done) {
    if (state.db){
        return done();
    }

    mongoClient.connect(url, function (err, db) {
        if (err){
            return done(err);
        }
        state.db = db
        done();
    })
}

exports.get = Promise.method(function () {
    return state.db
});

exports.close = function (done) {
    if (state.db) {
        state.db.close(function (err, result) {
            state.db = null
            state.mode = null
            done(err, result)
        })
    }
}